@@ -5,7 +5,7 @@ use warnings;
 use Dancer2::Plugin;
 use Dancer2::Plugin::Cart::InlineViews;
 use JSON;
-our $VERSION = '0.0005';  #Version
+our $VERSION = '0.0006';  #Version
 
 
 BEGIN{
@@ -599,7 +599,7 @@ Dancer2::Plugin::Cart - Cart interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0005
+version 0.0006
 
 =head1 SYNOPSIS
 
@@ -710,6 +710,10 @@ Add defautl adjustments to the ec_cart structure. The default adjustments are:
 
     YourSole Core Developers
 
+=head1 CONTRIBUTORS
+
+    Josh Lavin
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by Ruben Amortegui.
